/*
 * window_main.h
 * Copyright (C) Aitor Cuadrado Zubizarreta <aitor_czr@gnuinos.org>
 * 
 * wmlogut is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * simple-netaid is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * See the COPYING file. * 
 */

#ifndef __WINDOW_MAIN_H__
#define __WINDOW_MAIN_H__

#include <gtkmm.h>

// Forward declarations:
class Config;

// WindowMain (GTK+) callbacks:
void screen_changed(GtkWidget*, GdkScreen*, gpointer);
gboolean expose(GtkWidget*, GdkEventExpose*, gpointer);
void clicked(GtkWindow*, GdkEventButton*, gpointer);

class WindowMain : public Gtk::Window
{
public:
	WindowMain(Config*);
	virtual ~WindowMain();

protected:
	// Child Widgets:
	Gtk::HBox m_HBox;
	Gtk::Alignment m_Align1, m_Align2;
	Gtk::Image m_Image;
	Gtk::Button *m_ShutdownButton;
	Gtk::Button *m_CancelButton;
	Gtk::Button *m_RebootButton;
	Gtk::Button *m_LogoutButton;
	
	//Signal handlers:
	void on_shutdown_clicked(Config*);
	void on_cancel_clicked();
	void on_reboot_clicked(Config*);
	void on_logout_clicked(Config*);
	
	// Friend functions - WindowMain (GTK+) callbacks:
	friend void screen_changed(GtkWidget*, GdkScreen*, gpointer);
	friend gboolean expose(GtkWidget*, GdkEventExpose*, gpointer);
	friend void clicked(GtkWindow*, GdkEventButton*, gpointer);
};



#endif //__WINDOW_MAIN_H__
